
From: Jesper Juhl <juhl-lkml@dif.dk>

The preempt_count member of struct thread_info is currently either defined
as int, unsigned int or __s32 depending on arch.  This patch makes the type
of preempt_count an int on all archs.

Having preempt_count be an unsigned type prevents the catching of
preempt_count < 0 bugs, and using int on some archs and __s32 on others is
not exactely "neat" - much nicer when it's just int all over.

A previous version of this patch was already ACK'ed by Robert Love, and the
only change in this version of the patch compared to the one he ACK'ed is
that this one also makes sure the preempt_count member is consistently
commented.

Signed-off-by: Jesper Juhl <juhl-lkml@dif.dk>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/asm-arm/thread_info.h       |    2 +-
 include/asm-arm26/thread_info.h     |    2 +-
 include/asm-cris/thread_info.h      |    2 +-
 include/asm-frv/thread_info.h       |    2 +-
 include/asm-h8300/thread_info.h     |    2 +-
 include/asm-i386/thread_info.h      |    2 +-
 include/asm-ia64/thread_info.h      |    2 +-
 include/asm-m32r/thread_info.h      |    2 +-
 include/asm-m68k/thread_info.h      |    2 +-
 include/asm-m68knommu/thread_info.h |    2 +-
 include/asm-mips/thread_info.h      |    2 +-
 include/asm-parisc/thread_info.h    |    2 +-
 include/asm-ppc/thread_info.h       |    3 ++-
 include/asm-ppc64/thread_info.h     |    2 +-
 include/asm-s390/thread_info.h      |    2 +-
 include/asm-sh/thread_info.h        |    2 +-
 include/asm-sh64/thread_info.h      |    2 +-
 include/asm-sparc/thread_info.h     |    4 ++--
 include/asm-sparc64/thread_info.h   |    2 +-
 include/asm-um/thread_info.h        |    2 +-
 include/asm-v850/thread_info.h      |    3 ++-
 include/asm-x86_64/thread_info.h    |    2 +-
 22 files changed, 25 insertions(+), 23 deletions(-)

diff -puN include/asm-arm26/thread_info.h~streamline-preempt_count-type-across-archs include/asm-arm26/thread_info.h
--- 25/include/asm-arm26/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-arm26/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -44,7 +44,7 @@ struct cpu_context_save {
  */
 struct thread_info {
 	unsigned long		flags;		/* low level flags */
-	__s32			preempt_count;	/* 0 => preemptable, <0 => bug */
+	int			preempt_count;	/* 0 => preemptable, <0 => bug */
 	mm_segment_t		addr_limit;	/* address limit */
 	struct task_struct	*task;		/* main task structure */
 	struct exec_domain      *exec_domain;   /* execution domain */
diff -puN include/asm-arm/thread_info.h~streamline-preempt_count-type-across-archs include/asm-arm/thread_info.h
--- 25/include/asm-arm/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-arm/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -49,7 +49,7 @@ struct cpu_context_save {
  */
 struct thread_info {
 	unsigned long		flags;		/* low level flags */
-	__s32			preempt_count;	/* 0 => preemptable, <0 => bug */
+	int			preempt_count;	/* 0 => preemptable, <0 => bug */
 	mm_segment_t		addr_limit;	/* address limit */
 	struct task_struct	*task;		/* main task structure */
 	struct exec_domain	*exec_domain;	/* execution domain */
diff -puN include/asm-cris/thread_info.h~streamline-preempt_count-type-across-archs include/asm-cris/thread_info.h
--- 25/include/asm-cris/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-cris/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -31,7 +31,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 	mm_segment_t		addr_limit;	/* thread address space:
 					 	   0-0xBFFFFFFF for user-thead
diff -puN include/asm-frv/thread_info.h~streamline-preempt_count-type-across-archs include/asm-frv/thread_info.h
--- 25/include/asm-frv/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-frv/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -33,7 +33,7 @@ struct thread_info {
 	unsigned long		flags;		/* low level flags */
 	unsigned long		status;		/* thread-synchronous flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count;	/* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 	mm_segment_t		addr_limit;	/* thread address space:
 					 	   0-0xBFFFFFFF for user-thead
diff -puN include/asm-h8300/thread_info.h~streamline-preempt_count-type-across-archs include/asm-h8300/thread_info.h
--- 25/include/asm-h8300/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-h8300/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -23,7 +23,7 @@ struct thread_info {
 	struct exec_domain *exec_domain;	/* execution domain */
 	unsigned long	   flags;		/* low level flags */
 	int		   cpu;			/* cpu we're on */
-	int		   preempt_count;	/* 0 => preemptable, <0 => BUG*/
+	int		   preempt_count;	/* 0 => preemptable, <0 => BUG */
 	struct restart_block restart_block;
 };
 
diff -puN include/asm-i386/thread_info.h~streamline-preempt_count-type-across-archs include/asm-i386/thread_info.h
--- 25/include/asm-i386/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-i386/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -31,7 +31,7 @@ struct thread_info {
 	unsigned long		flags;		/* low level flags */
 	unsigned long		status;		/* thread-synchronous flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 
 	mm_segment_t		addr_limit;	/* thread address space:
diff -puN include/asm-ia64/thread_info.h~streamline-preempt_count-type-across-archs include/asm-ia64/thread_info.h
--- 25/include/asm-ia64/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-ia64/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -25,7 +25,7 @@ struct thread_info {
 	__u32 flags;			/* thread_info flags (see TIF_*) */
 	__u32 cpu;			/* current CPU */
 	mm_segment_t addr_limit;	/* user-level address space limit */
-	__s32 preempt_count;		/* 0=premptable, <0=BUG; will also serve as bh-counter */
+	int preempt_count;		/* 0=premptable, <0=BUG; will also serve as bh-counter */
 	struct restart_block restart_block;
 	struct {
 		int signo;
diff -puN include/asm-m32r/thread_info.h~streamline-preempt_count-type-across-archs include/asm-m32r/thread_info.h
--- 25/include/asm-m32r/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-m32r/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -28,7 +28,7 @@ struct thread_info {
 	unsigned long		flags;		/* low level flags */
 	unsigned long		status;		/* thread-synchronous flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 	mm_segment_t		addr_limit;	/* thread address space:
 					 	   0-0xBFFFFFFF for user-thread
diff -puN include/asm-m68knommu/thread_info.h~streamline-preempt_count-type-across-archs include/asm-m68knommu/thread_info.h
--- 25/include/asm-m68knommu/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-m68knommu/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -36,7 +36,7 @@ struct thread_info {
 	struct exec_domain *exec_domain;	/* execution domain */
 	unsigned long	   flags;		/* low level flags */
 	int		   cpu;			/* cpu we're on */
-	int		   preempt_count;	/* 0 => preemptable, <0 => BUG*/
+	int		   preempt_count;	/* 0 => preemptable, <0 => BUG */
 	struct restart_block restart_block;
 };
 
diff -puN include/asm-m68k/thread_info.h~streamline-preempt_count-type-across-archs include/asm-m68k/thread_info.h
--- 25/include/asm-m68k/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-m68k/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -8,7 +8,7 @@
 struct thread_info {
 	struct task_struct	*task;		/* main task structure */
 	struct exec_domain	*exec_domain;	/* execution domain */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 	__u32 cpu; /* should always be 0 on m68k */
 	struct restart_block    restart_block;
 
diff -puN include/asm-mips/thread_info.h~streamline-preempt_count-type-across-archs include/asm-mips/thread_info.h
--- 25/include/asm-mips/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:31.000000000 -0700
+++ 25-akpm/include/asm-mips/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -27,7 +27,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 	mm_segment_t		addr_limit;	/* thread address space:
 					 	   0-0xBFFFFFFF for user-thead
diff -puN include/asm-parisc/thread_info.h~streamline-preempt_count-type-across-archs include/asm-parisc/thread_info.h
--- 25/include/asm-parisc/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-parisc/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -12,7 +12,7 @@ struct thread_info {
 	unsigned long flags;		/* thread_info flags (see TIF_*) */
 	mm_segment_t addr_limit;	/* user-level address space limit */
 	__u32 cpu;			/* current CPU */
-	__s32 preempt_count;		/* 0=premptable, <0=BUG; will also serve as bh-counter */
+	int preempt_count;		/* 0=premptable, <0=BUG; will also serve as bh-counter */
 	struct restart_block restart_block;
 };
 
diff -puN include/asm-ppc64/thread_info.h~streamline-preempt_count-type-across-archs include/asm-ppc64/thread_info.h
--- 25/include/asm-ppc64/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-ppc64/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -24,7 +24,7 @@ struct thread_info {
 	struct task_struct *task;		/* main task structure */
 	struct exec_domain *exec_domain;	/* execution domain */
 	int		cpu;			/* cpu we're on */
-	int		preempt_count;
+	int		preempt_count;		/* 0 => preemptable, <0 => BUG */
 	struct restart_block restart_block;
 	/* set by force_successful_syscall_return */
 	unsigned char	syscall_noerror;
diff -puN include/asm-ppc/thread_info.h~streamline-preempt_count-type-across-archs include/asm-ppc/thread_info.h
--- 25/include/asm-ppc/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-ppc/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -20,7 +20,8 @@ struct thread_info {
 	unsigned long		flags;		/* low level flags */
 	unsigned long		local_flags;	/* non-racy flags */
 	int			cpu;		/* cpu we're on */
-	int			preempt_count;
+	int			preempt_count;	/* 0 => preemptable,
+						   <0 => BUG */
 	struct restart_block	restart_block;
 };
 
diff -puN include/asm-s390/thread_info.h~streamline-preempt_count-type-across-archs include/asm-s390/thread_info.h
--- 25/include/asm-s390/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-s390/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -50,7 +50,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	unsigned int		cpu;		/* current CPU */
-	unsigned int		preempt_count; /* 0 => preemptable */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 	struct restart_block	restart_block;
 };
 
diff -puN include/asm-sh64/thread_info.h~streamline-preempt_count-type-across-archs include/asm-sh64/thread_info.h
--- 25/include/asm-sh64/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-sh64/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -22,7 +22,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	/* Put the 4 32-bit fields together to make asm offsetting easier. */
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 	__u16			cpu;
 
 	mm_segment_t		addr_limit;
diff -puN include/asm-sh/thread_info.h~streamline-preempt_count-type-across-archs include/asm-sh/thread_info.h
--- 25/include/asm-sh/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-sh/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -20,7 +20,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	__u32			flags;		/* low level flags */
 	__u32			cpu;
-	__s32			preempt_count; /* 0 => preemptable, <0 => BUG */
+	int			preempt_count; /* 0 => preemptable, <0 => BUG */
 	struct restart_block	restart_block;
 	__u8			supervisor_stack[0];
 };
diff -puN include/asm-sparc64/thread_info.h~streamline-preempt_count-type-across-archs include/asm-sparc64/thread_info.h
--- 25/include/asm-sparc64/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-sparc64/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -46,7 +46,7 @@ struct thread_info {
 	unsigned long		fault_address;
 	struct pt_regs		*kregs;
 	struct exec_domain	*exec_domain;
-	int			preempt_count;
+	int			preempt_count;	/* 0 => preemptable, <0 => BUG */
 	int			__pad;
 
 	unsigned long		*utraps;
diff -puN include/asm-sparc/thread_info.h~streamline-preempt_count-type-across-archs include/asm-sparc/thread_info.h
--- 25/include/asm-sparc/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-sparc/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -30,9 +30,9 @@ struct thread_info {
 	struct task_struct	*task;		/* main task structure */
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
-
 	int			cpu;		/* cpu we're on */
-	int			preempt_count;
+	int			preempt_count;	/* 0 => preemptable,
+						   <0 => BUG */
 	int			softirq_count;
 	int			hardirq_count;
 
diff -puN include/asm-um/thread_info.h~streamline-preempt_count-type-across-archs include/asm-um/thread_info.h
--- 25/include/asm-um/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-um/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -17,7 +17,7 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	__u32			cpu;		/* current CPU */
-	__s32			preempt_count;  /* 0 => preemptable, 
+	int			preempt_count;  /* 0 => preemptable,
 						   <0 => BUG */
 	mm_segment_t		addr_limit;	/* thread address space:
 					 	   0-0xBFFFFFFF for user
diff -puN include/asm-v850/thread_info.h~streamline-preempt_count-type-across-archs include/asm-v850/thread_info.h
--- 25/include/asm-v850/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-v850/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -30,7 +30,8 @@ struct thread_info {
 	struct exec_domain	*exec_domain;	/* execution domain */
 	unsigned long		flags;		/* low level flags */
 	int			cpu;		/* cpu we're on */
-	int			preempt_count;
+	int			preempt_count;	/* 0 => preemptable,
+						   <0 => BUG */
 	struct restart_block	restart_block;
 };
 
diff -puN include/asm-x86_64/thread_info.h~streamline-preempt_count-type-across-archs include/asm-x86_64/thread_info.h
--- 25/include/asm-x86_64/thread_info.h~streamline-preempt_count-type-across-archs	2005-05-09 20:09:32.000000000 -0700
+++ 25-akpm/include/asm-x86_64/thread_info.h	2005-05-09 20:09:32.000000000 -0700
@@ -29,7 +29,7 @@ struct thread_info {
 	__u32			flags;		/* low level flags */
 	__u32			status;		/* thread synchronous flags */
 	__u32			cpu;		/* current CPU */
-	int 			preempt_count;
+	int 			preempt_count;	/* 0 => preemptable, <0 => BUG */
 
 	mm_segment_t		addr_limit;	
 	struct restart_block    restart_block;
_
